import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

// Data set URI
const csvUrl = 'https://gist.githubusercontent.com/pavankalyan1507/0b2d1048155c44cd79b710817ebb4854/raw/1deedc3ff670e27fc65081d3a92f2c380abe1e97/petals';  

// Format the Data from the URI response
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  
  // Creating a new Scatter Plot object
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5);

  // Plotting the Scatter Plot axes based on the given parameters
  svg.call(plot);

  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  
  // Plotting the data on the Scatter Plot
  let i = 0;
 	plot.xValue((d) => d[columns[i % columns.length]]);
  svg.call(plot);
};
main();



